@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -698,6 +698,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSubAccounts(self, request):
+        """通过子用户UIN列表查询子用户
+
+        :param request: Request instance for DescribeSubAccounts.
+        :type request: :class:`tencentcloud.cam.v20190116.models.DescribeSubAccountsRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.DescribeSubAccountsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeSubAccounts", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSubAccountsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DetachGroupPolicy(self, request):
         """本接口（DetachGroupPolicy）可用于解除绑定到用户组的策略。
 
@@ -1370,6 +1398,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ListWeChatWorkSubAccounts(self, request):
+        """获取企业微信子用户列表
+
+        :param request: Request instance for ListWeChatWorkSubAccounts.
+        :type request: :class:`tencentcloud.cam.v20190116.models.ListWeChatWorkSubAccountsRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.ListWeChatWorkSubAccountsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListWeChatWorkSubAccounts", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListWeChatWorkSubAccountsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def PutRolePermissionsBoundary(self, request):
         """设置角色权限边界
 
